@@ -7,9 +7,10 @@ from contextlib import contextmanager
 
 import numpy as np
 import pandas as pd
+import pyarrow as pa
 from numpy.testing import assert_allclose
 
-from parquery import df_to_parquet, aggregate_pq
+from parquery import df_to_parquet, aggregate_pq, serialize_pa_table, deserialize_pa_table
 
 
 class TestParquery(object):
@@ -851,3 +852,122 @@ class TestParquery(object):
 
         # compare
         assert all(a == b for a, b in zip([list(x) for x in result_parquery.to_numpy()], ref))
+
+    def test_where_terms_05(self):
+        """
+        test_where_terms05: get mask where terms in list with a filter on unused column without aggregation
+        """
+
+        include = [0, 1000, 2000]
+
+        # expected result
+        ref = [[x] for x in range(20000) if x in include]
+
+        # generate data to filter on
+        iterable = ((x, x) for x in range(20000))
+        data = np.fromiter(iterable, dtype='i8,i8')
+
+        self.filename = tempfile.mkstemp(prefix='test-')[-1]
+        df_to_parquet(pd.DataFrame(data), self.filename)
+
+        # filter data
+        terms_filter = [('f0', 'in', include)]
+        result_parquery = aggregate_pq(self.filename, [], ['f1'],
+                                       data_filter=terms_filter,
+                                       aggregate=False)
+
+        # compare
+        assert all(a == b for a, b in zip([list(x) for x in result_parquery.to_numpy()], ref))
+
+    def test_where_terms_06(self):
+        """
+        test_where_terms06: get mask where terms in list with a filter on unused column with aggregation
+        """
+
+        include = [0, 1000, 2000]
+
+        # expected result
+        ref = [[x] for x in range(20000) if x == 0 + 1000 + 2000]
+
+        # generate data to filter on
+        iterable = ((x, x) for x in range(20000))
+        data = np.fromiter(iterable, dtype='i8,i8')
+
+        self.filename = tempfile.mkstemp(prefix='test-')[-1]
+        df_to_parquet(pd.DataFrame(data), self.filename)
+
+        # filter data
+        terms_filter = [('f0', 'in', include)]
+        result_parquery = aggregate_pq(self.filename, [], ['f1'],
+                                       data_filter=terms_filter,
+                                       aggregate=True)
+
+        # compare
+        assert all(a == b for a, b in zip([list(x) for x in result_parquery.to_numpy()], ref))
+
+    def test_natural_notation(self):
+        """
+        test_natural_notation: check the handling of difficult naming
+        """
+
+        include = [0, 1000, 2000]
+
+        # expected result
+        ref = [[x, x] for x in range(20000) if x in [0, 1000, 2000]]
+
+        # generate data to filter on
+        iterable = ((x, x, x) for x in range(20000))
+        data = np.fromiter(iterable, dtype='i8,i8,i8')
+        df = pd.DataFrame(data)
+        df.columns = ['d-1', 'd-2', 'm-1']
+
+        self.filename = tempfile.mkstemp(prefix='test-')[-1]
+        df_to_parquet(df, self.filename)
+
+        # filter data
+        terms_filter = [('d-1', 'in', include)]
+        result_parquery = aggregate_pq(self.filename, ['d-2'], ['m-1'],
+                                       data_filter=terms_filter,
+                                       aggregate=True)
+
+        # compare
+        assert all(a == b for a, b in zip([list(x) for x in result_parquery.to_numpy()], ref))
+
+    def test_natural_notation_2(self):
+        """
+        test_natural_notation: check the handling of difficult naming without dimensions
+        """
+
+        include = [0, 1000, 2000]
+
+        # expected result
+        ref = [[x] for x in range(20000) if x == 0 + 1000 + 2000]
+
+        # generate data to filter on
+        iterable = ((x, x, x) for x in range(20000))
+        data = np.fromiter(iterable, dtype='i8,i8,i8')
+        df = pd.DataFrame(data)
+        df.columns = ['d-1', 'd-2', 'm-1']
+
+        filename = tempfile.mkstemp(prefix='test-')[-1]
+        df_to_parquet(df, filename)
+
+        # filter data
+        terms_filter = [('d-1', 'in', include)]
+        result_parquery = aggregate_pq(filename, [], ['m-1'],
+                                       data_filter=terms_filter,
+                                       aggregate=True)
+
+        # compare
+        assert all(a == b for a, b in zip([list(x) for x in result_parquery.to_numpy()], ref))
+
+    def test_pa_serialization(self):
+        iterable = ((x, x) for x in range(20000))
+        data = np.fromiter(iterable, dtype='i8,i8')
+        df = pd.DataFrame(data)
+
+        data_table = pa.Table.from_pandas(df, preserve_index=False)
+        buf = serialize_pa_table(data_table)
+        data_table_2 = deserialize_pa_table(buf)
+
+        assert data_table == data_table_2
